<?php
/**
 * 随行付天阙通道 商户、微信/支付宝支付基础API
 * @category   api
 * Created by PhpStorm.
 * User: roc
 * Date: 2019/11/06
 * Time: 11:56
 */

namespace kwy\sxf\lib\tianque;

use kwy\util\http\CurlHttp;

class SxfApi{

    /**
     * @var CurlHttp
     */
    private $httpClient;

    //合作方id
    protected $org_id = "";

    //合作方私钥
    protected $private_key = "";

    //随行付公钥
    protected $sxf_public_key = "";

    //随行付域名
    protected $host = "";

    /**
     * 设置合作机构id
     * @author roc
     * @param $org_id
     */
    public function setOrgId($org_id){
        $this->org_id = $org_id;
    }

    /**
     * 获取合作机构id
     * @author roc
     * @return string
     */
    public function getOrgId(){
        return $this->org_id;
    }

    /**
     * 设置合作方（客无忧）私钥
     * @author roc
     * @param $private_key
     */
    public function setPrivateKey($private_key){
        $this->private_key = $private_key;
    }

    /**
     * 获取合作方（客无忧）私钥
     * @author roc
     * @return string
     */
    public function getPrivateKey(){
        return $this->private_key;
    }

    /**
     * 设置随行付公钥
     * @author roc
     * @param $public_key
     */
    public function setPublicKey($public_key){
        $this->sxf_public_key = $public_key;
    }

    /**
     * 获取随行付公钥
     * @author roc
     * @return string
     */
    public function getPublicKey(){
        return $this->sxf_public_key;
    }

    /**
     * 设置随行付请求域名地址
     * @author roc
     * @param $host
     */
    public function setHost($host){
        $this->host = $host;
    }

    /**
     * 获取随行付请求域名地址
     * @author roc
     * @return string
     */
    public function getHost(){
        return $this->host;
    }

    /**
     * 获取随行付签名
     * @author roc
     * @param string $own_params 待签名数据
     * @return string 签名结果
     * @throws \Exception
     */
    protected function getSign($own_params) {
        if(empty($this->private_key)) throw new \Exception("合作方私钥未设置");

        ksort($own_params);
        $params = [];
        foreach($own_params as $key => $value){
            if(is_array($value)){
                $value=stripslashes(json_encode($value,JSON_UNESCAPED_UNICODE));
            }
            $params[] = $key .'='. $value ;
        }
        $data = implode("&", $params);
        $res = openssl_get_privatekey($this->private_key);
        openssl_sign($data, $sign, $res);
        openssl_free_key($res);
        //base64编码
        $sign = base64_encode($sign);
        return $sign;
    }

    /**
     * 签名认证校验
     * @param $params
     * @return bool
     */
    public function checkSign($params){
        $sign = $params['sign'];
        unset($params['sign']);
        ksort($params);
        $signParams = [];
        foreach($params as $key => $value){
            if(is_array($value)){
                $value=stripslashes(json_encode($value,JSON_UNESCAPED_UNICODE));
            }
            $signParams[] = $key .'='. $value ;
        }
        $data = implode("&", $signParams);
        $res = openssl_pkey_get_public($this->sxf_public_key);
        $sign = base64_decode($sign);
        $result = (bool)openssl_verify($data, $sign, $res);
        openssl_free_key($res);
        return $result;
    }

    /**
     * 设置代理
     * @author roc
     * @datetime:2019/12/8 14:37
     * @param $proxy
     * @return $this
     */
    public function setProxy($proxy){
        $this->getHttpClient()->setProxy($proxy);
        return $this;
    }

    /**
     * 获取http请求客户端
     * @author roc
     * @return CurlHttp
     */
    public function getHttpClient(){
        if (empty($this->httpClient)){
            $this->httpClient = new CurlHttp();
            //$this->httpClient->setProxy('127.0.0.1:8888');
            $this->httpClient->setContentType('application/json');
        }
        return $this->httpClient;
    }

    /**
     * 获取请求编号
     * @return string
     */
    protected function getReqId(){
        $chars = "abcdefghijklmnopqrstuvwxyz0123456789";
//        $str ="";
        $str = date("YmdHis")."";
        $len=16;
        for ( $i = 0; $i < $len; $i++ )  {
            $str.= substr($chars, mt_rand(0, strlen($chars)-1), 1);
        }
        return $str;
    }
}