<?php
namespace kwy\sxf\lib\tianque\mch;
use kwy\sxf\lib\tianque\SxfApi;

/**
 * Created by PhpStorm.
 * User: roc
 * Date: 2019/12/3
 * Time: 20:42
 */

/**
 * 随行付天阙商户通道类
 * Class Mch
 * @package kwy\sxf\lib\tianque\mch
 */
class Mch extends SxfApi
{

    /**
     * 5.1 图片上传
     * @author roc
     * @param string $pic_path 本地图片路径
     * @param string $pictureType 图片类型:
                                01 税务登记证
                                02 法人身份证正面(人像面)
                                03 法人身份证反面(国徽面)
                                04 开户许可证
                                05 银行卡正面
                                06 银行卡反面
                                07 结算人身份证反面(国徽面)
                                08 结算人身份证正面(人像面)
                                09 商户协议照片
                                10 门头照
                                11 内景照
                                12 收银台照
                                13 营业执照
                                14 组织机构代码证
                                15 手持身份证(人像面)照片
                                16 租赁协议一(封面)
                                17 租赁协议二(面积、有效期页)
                                18 租赁协议三(签章页)
                                19 其他资料照片(1)
                                20 其他资料照片(2)
                                21 其他资料照片(3)
                                22 其他资料照片(4)
                                23 其他资料照片(5)
                                24 代理人签名
                                25 确认人签名
                                26 非法人结算授权函
                                27 统一结算无营业执照说明
                                28 商家入驻协议
                                29 ICP 许可证或公众号主体信息截图
                                30 新旧结算人手持身份证 合照
                                31 商户信息变更表
                                32 社会团体法人证书
                                33 基金会法人登记证书
                                34 办学许可证
                                35 医疗机构办学许可证
                                36 经营保险业务许可证
                                37 保险业务法人等级证书
                                38 民办教育许可证
                                39 收费证明文件
     * @return mixed
     * @throws \Exception
     */
    public function uploadPic($pic_path,$pictureType){
        $url = $this->host."merchant/uploadPicture";
        $requestData = [
            'orgId' => $this->org_id,  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'signType' => 'RSA',    //签名类型
            "pictureType" => $pictureType,  //
        ];
        $requestData['sign'] = $this->getSign($requestData);
        $requestData['file'] = curl_file_create($pic_path);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("multipart/form-data")
                ->post($requestData);

            /**
             * 随心付返回数据
             * array (
            'code' => '0000',
            'msg' => '操作成功',
            'reqId' => '201912040245194779',
            'orgId' => '41785179',
            'signType' => NULL,
            'respData' =>
            array (
            'bizMsg' => '上传成功',
            'cdnUrl' => 'https://oss-test.suixingpay.com/0/2/32MDJhYjIyYWZLNURkaDJheDIwMTlfMTJfMDRfMTBfNDVfOTMxZjM1NjcwZGY5NDE2NGFkMzEwOGE3YzdhMjAxOGMyYWd0ZXN0XzEyYWIx.jpg',
            'bizCode' => '0000',
            'PhotoUrl' => '5376f6ea458549b192a4d8b68f94116d',
            ),
            'sign' => NULL,
            )
             */
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            $resultData = $result['respData'];
            if (empty($resultData['PhotoUrl'])){
                throw new \Exception($resultData['bizMsg']);
            }
            return $resultData['PhotoUrl'];

        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.2 商户入驻
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function inCome($data){
        $url = $this->host."merchant/income";
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.3 商户入驻修改
     * 本接口应用于进件审核失败的情况。对于审核驳回的进件信息，合作方调用此接口 修改商户信息后重新进件。合作方通过商户入驻结果查询接口获取审核结果。
    注意:1、只有审核驳回、图片驳回的商户可调用此接口进行修改后重新提交进件; 2、图片驳回的商户只能用此接口修改图片后重新提交，审核驳回的商户可修改全 部信息。
     * @param $mch_id
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function updateMerchantInfo($mch_id,$data){
        $url = $this->host."merchant/updateMerchantInfo";
        $data["mno"] = $mch_id;
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.4 入驻结果查询接口
     * @author roc
     * @param string $application_id 进件申请ID
     * @param string $mch_id 商编(暂未启用
     * @return mixed
     * @throws \Exception
     */
    public function queryMerchantInfo($application_id='',$mch_id=''){
        $url = $this->host."merchant/queryMerchantInfo";
        $reqData = [];
        if(!empty($application_id)) $reqData["applicationId"] = $application_id;
        if(!empty($mch_id)) $reqData["mno"] = $mch_id;
        if(empty($reqData)) throw new \Exception('进件申请ID和商编必填一个');

        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $reqData, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.5 商户信息修改接口
     * 合作方通过本接口对已经成功进件的商户进行商户信息修改。商户信息修改是异步 流程，需人工审核，审核通过后生效。可通过商户信息修改结果查询接口获取审核结果。
     * @param $mch_id
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function editMerchantInfo($mch_id,$data){
        $url = $this->host."merchant/editMerchantInfo";
        $data["mno"] = $mch_id;
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.6 商户修改结果查询
     * @param string $application_id 修改申请ID
     * @param $data
     * @return mixed
     * @throws \Exception
     */
    public function queryModifyResult($application_id,$data){
        $url = $this->host."merchant/queryModifyResult";
        $data["applicationId"] = $application_id;
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.7 商户设置
     * 合作方通过本接口修改商户功能信息。区别于商户信息修改接口，本接口是同步流程，调用成功即生效(费率次日0点生效)。
     * @author roc
     * @datetime:2019/12/8 15:22
     * @param string $mch_id 随行付天阙商户号
     * @param array $qr_code_list 二维码费率数组
     * @param string $settle_type 结算类型
     * @return boolean
     * @throws \Exception
     */
    public function merchantSetup($mch_id,$qr_code_list,$settle_type="04"){
        $url = $this->host."merchant/merchantSetup";
        $data = [
            "mno" => $mch_id,   //商户号
            "qrcodeList" => $qr_code_list,  //二维码费率(费率单位为%) ;01 微信;02 支付宝;06 银联单笔小于 1000;07 银联单笔大于 1000 修改费率必须完整传入(同时包含微信、支付宝、银联二维码);注:费率修改成功后，次日0点生效
            "settleType" => $settle_type,   //结算类型;取值范围:03:T1;04:D1
//            "supportPayChannels" => ["01","02","03"],   //支持的支付渠道;取值范围:01 支付宝 02 微信 03 银联二维码
//            "supportTradeTypes" => ["01","02","03","04", "05" ],    //支持的交易类型;取值范围:01 主扫 02 被扫 03 公众号/小程序/服务窗/银联JS 04 退货 05 APP 多选，逗号间隔。
        ];
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return true;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.8 商户信息查询
     * @param $mch_id
     * @return mixed
     * @throws \Exception
     */
    public function merchantInfoQuery($mch_id){
        $url = $this->host."merchant/merchantInfoQuery";
        $data["mno"] = $mch_id;
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.9 微信子商户支付参数配置
     * 合作方通过本接口配置微信子商户的授权目录、支付 APPID、默认关注APPID。
     * @author roc
     * @datetime:2019/12/8 15:27
     * @param string $mch_id 随行付天阙商户号
     * @param string $sub_mch_id 微信子商户号
     * @param string $type 配置类型;取值范围:01 支付 Appid 02 关注 Appid 03 jsapi 授权目录
     * @param string $sub_appid
     * @param string $subscribe_appid
     * @param string $receipt_appid
     * @param string $jsapi_path
     * @return boolean
     * @throws \Exception
     */
    public function addWeChatConf($mch_id,$sub_mch_id,$type,$sub_appid="",$subscribe_appid="",$receipt_appid="",$jsapi_path=""){
        $url = $this->host."merchant/weChatPaySet/addConf";
        $data = [
            "mno" => $mch_id,   //商户号
            "subMchId" => $sub_mch_id,   //微信子商户号
            "type" => $type,  //配置类型；取值范围:01:支付Appid;02:关注Appid;03:jsapi 授权目录
        ];
        switch ($type){
            case "01":
                //支付 Appid；配置类型为 01，02 时必传
                $data['subAppid'] = $sub_appid;
                break;
            case "02":
                //推荐关注公众号 Appid  或者 推荐关注小程序 Appid
                //配置类型为 02 时与推荐关注公众号 Appid 二选一
                $data['subAppid'] = $sub_appid;
                if(!empty($subscribe_appid)) $data['subscribeAppid'] = $subscribe_appid;
                if(!empty($receipt_appid)) $data['receiptAppid'] = $receipt_appid;
                break;
            case "03":  //jsapi 授权目录
                $data['jsapiPath'] = $jsapi_path;
                break;
            default:
                throw new \Exception("错误的配置类型");
                break;
        }
        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return true;
        }catch (\Exception $e){
            throw $e;
        }
    }

    /**
     * 5.9 微信子商户支付参数查询
     * 合作方通过本接口配置微信子商户的授权目录、支付 APPID、默认关注APPID。
     * @author roc
     * @datetime:2019/12/8 15:27
     * @param string $mch_id 随行付天阙商户号
     * @param string $sub_mch_id 微信子商户号
     * @return mixed
     * @throws \Exception
     */
    public function queryWeChatConf($mch_id,$sub_mch_id){
        $url = $this->host."merchant/weChatPaySet/queryConf";
        $data = ["mno" => $mch_id,   //商户号
            "subMchId" => $sub_mch_id,   //微信子商户号
        ];

        $requestData = [
            'orgId' => $this->getOrgId(),  //合作机构 id
            'reqId' => $this->getReqId(),    //请求 id
            'version' => '1.0', //版本
            'timestamp' => date("YmdHis"),  //请求时间
            'reqData' => $data, //业务数据
            'signType' => 'RSA',    //签名类型
        ];
        $requestData['sign'] = $this->getSign($requestData);

        try{
            $response = $this->getHttpClient()
//                ->setProxy('127.0.0.1:8888')
                ->setUrl($url)
                ->setContentType("application/json;charset=utf-8")
                ->post(json_encode($requestData));

//            echo $response."\n";
            $result = json_decode($response,true);

            if(empty($result)) throw new \Exception('请求随行付服务器异常');
            if($result['code'] != '0000'){
                throw new \Exception($result['msg']);
            }

            //业务返回码判断
            $respData = $result["respData"];
            if(empty($respData['bizCode']) || $respData['bizCode'] != "0000"){
                throw new \Exception($respData["bizMsg"]);
            }
            return $respData;
        }catch (\Exception $e){
            throw $e;
        }
    }

}